require(['config'], function() {
	require([
		'kakao.map.util'
	], function($) {
		pageObj.init();
	});
});

/********************************************************
 --------------------------------------------------------
 - Object 목록								            -
 --------------------------------------------------------
 * const gridColModel = {}	: 화면 Grid Object			*
 * let pageObj = {}			: 화면공통 Object			*
 * let listObj = {}			: 목록화면 Object			*
 * let viewObj = {}			: 상세화면 Object			*
 * let modifyObj = {}		: 수정화면 Object			*
 * let createObj = {}		: 신규화면 Object			*
 *******************************************************/

/*화면 변수*/
const POMNG03010_GRID_ID = '#ITP_POMNG03010_jqGrid';
const POMNG03010_GRID_LIST = '#ITP_POMNG03010_jqGrid_list';
const POMNG03010_GRID_PAGER = '#ITP_POMNG03010_jqGridPager';
const POMNG03010_GRID_EMPTY = '#ITP_POMNG03010_jqGridEmpty';

const POMNG03010_DETAIL_GRID_ID = '#ITP_POMNG03010_DETAIL_jqGrid';
const POMNG03010_DETAIL_GRID_LIST = '#ITP_POMNG03010_DETAIL_jqGrid_list';
const POMNG03010_DETAIL_GRID_PAGER = '#ITP_POMNG03010_DETAIL_jqGridPager';
const POMNG03010_DETAIL_GRID_EMPTY = '#ITP_POMNG03010_DETAIL_jqGridEmpty';

const POMNG03010_NDETAIL_GRID_ID = '#ITP_POMNG03010_NDETAIL_jqGrid';
const POMNG03010_NDETAIL_GRID_LIST = '#ITP_POMNG03010_NDETAIL_jqGrid_list';
const POMNG03010_NDETAIL_GRID_PAGER = '#ITP_POMNG03010_NDETAIL_jqGridPager';
const POMNG03010_NDETAIL_GRID_EMPTY = '#ITP_POMNG03010_NDETAIL_jqGridEmpty';

let ITP_FORM_POMNG03010_DETAIL_IS_WRITING = false;

/*API URL*/
let API_DETAIL_GRID_LIST 		= '/api/pomng/po-target-grid-list';	// 목록
let API_DETAIL_REJECT_LIST  	= '/api/pomng/reject-pchreq-target'; // 구매요청 선택한건 반려 처리 대상 리스트 
let API_DETAIL_POPASS_CHK   	= '/api/pomng/po/chk-pchOrd'; // 목록에서 선택한 구매요청건에 대해 발주가능여부 체크 함
let API_DETAIL_PO_INIT_INFO    	= '/api/pomng/po/init-pchOrd'; // 구매요청발주생성 오픈시 호출하여 데이타 세팅함
let API_DETAIL_NEW_INIT_INFO    = '/api/pomng/po/init-poOrd'; // 신규발주생성 오픈시 호출하여 데이타 세팅함
let API_DETAIL_SAVE 		    = '/api/pomng/po/save-pchPo';			// 저장


/*화면 Grid ColModel*/
const gridColModel = {
	list: [
		{
			index: 'PCH_REQ_UNQ_NO', name: 'pchReqUnqNo',
			label: ITP_MSG_LOCALE.label.pchReqUnqNo, //구매요청고유번호
			width: '10', fixed: false, align: 'center',
			sortable: false, hidden: true
		},
		{
			index: 'PCH_REQ_DTL_NO', name: 'pchReqDtlNo',
			label: ITP_MSG_LOCALE.label.pchReqDtlNo, //구매요청상세번호
			width: '13', fixed: false, align: 'center',
			sortable: false, hidden: true
		},
		{
			index: 'BRAND_ID', name: 'brandId',
			label: ITP_MSG_LOCALE.label.brandId, //브랜드ID
			width: '10', fixed: false, align: 'center',
			sortable: false, hidden: true
		},
		{
			index: 'BRAND_NM', name: 'brandNm',
			label: ITP_MSG_LOCALE.label.brandNm, //브랜드명
			width: '10', fixed: false, align: 'center',
			sortable: false, hidden: false
		},
		{
			index: 'STORE_ID', name: 'storeId',
			label: ITP_MSG_LOCALE.label.storeId, //매장아이디
			width: '13', fixed: false, align: 'center',
			sortable: false, hidden: true
		},
		{
			index: 'STORE_NM', name: 'storeNm',
			label: ITP_MSG_LOCALE.label.storeNm, //매장명
			width: '15', fixed: false, align: 'center',
			sortable: false, hidden: true
		},
		{
			index: 'SPPLY_ID', name: 'spplyId',
			label: ITP_MSG_LOCALE.label.spplyId, //공급사아이디
			width: '15', fixed: false, align: 'center',
			sortable: false, hidden: true
		},
		{
			index: 'SPPLY_NM', name: 'spplyNm',
			label: ITP_MSG_LOCALE.label.spplyNm, //공급사명
			width: '6', fixed: false, align: 'left',
			sortable: false, hidden: false
		},
		{
			index: 'WHS_ID', name: 'whsId',
			label: ITP_MSG_LOCALE.label.whsId, //창고아이디
			width: '10', fixed: false, align: 'center',
			sortable: false, hidden: true
		},
		{
			index: 'WHS_NM', name: 'whsNm',
			label: ITP_MSG_LOCALE.label.whsNm, //창고명
			width: '10', fixed: false, align: 'left',
			sortable: false, hidden: false
		},
		{
			index: 'LOCATION', name: 'location',
			label: ITP_MSG_LOCALE.label.location, //창고상세코드
			width: '10', fixed: false, align: 'center',
			sortable: false, hidden: true
		},
		{
			index: 'LOCATION_NM', name: 'locationNm',
			label: ITP_MSG_LOCALE.label.locationNm, //창고상세명
			width: '10', fixed: false, align: 'center',
			sortable: false, hidden: true
		},
		{
			index: 'ITEM_ID', name: 'itemId',
			label: ITP_MSG_LOCALE.label.itemId, //품목아이디
			width: '10', fixed: false, align: 'center',
			sortable: false, hidden: false
		},
		{
			index: 'ITEM_NM', name: 'itemNm',
			label: ITP_MSG_LOCALE.label.itemNm, //품목명
			width: '10', fixed: false, align: 'left',
			sortable: false, hidden: false
		},
		{
			index: 'UNIT_AMT', name: 'unitAmt',
			label: ITP_MSG_LOCALE.label.unitAmt, //구매요청단가
			width: '10', fixed: false, align: 'right',
			sortable: false, hidden: true
		},
		{
			index: 'PO_UNIT_AMT', name: 'poUnitAmt',
			label: ITP_MSG_LOCALE.label.poUnitAmt, //발주단가
			width: '10', fixed: false, align: 'right',
			sortable: false, hidden: true
		},
		{
			index: 'PCH_REQ_QTY', name: 'pchReqQty',
			label: ITP_MSG_LOCALE.label.pchReqQty, //구매요청수량
			width: '10', fixed: false, align: 'right',
			sortable: false, hidden: false
		},
		{
			index: 'DLV_REQ_DT', name: 'dlvReqDt',
			label: ITP_MSG_LOCALE.label.dlvReqDt, //납품요청일
			width: '10', fixed: false, align: 'center',
			sortable: false, hidden: false
		},
		{
			index: 'PCH_REQ_AMT', name: 'pchReqAmt',
			label: ITP_MSG_LOCALE.label.pchReqAmt, //납품요청금액
			width: '10', fixed: false, align: 'right',
			sortable: false, hidden: false
		},
		{
			index: 'PCH_ORD_AMT', name: 'pchOrdAmt',
			label: ITP_MSG_LOCALE.label.pchOrdSpplyAmt, //본사납품금액
			width: '10', fixed: false, align: 'right',
			sortable: false, hidden: false
		},
		{
			index: 'LEAD_TIME', name: 'leadTime',
			label: ITP_MSG_LOCALE.label.leadTime, //리드타임
			width: '10', fixed: false, align: 'right',
			sortable: false, hidden: false
		}
	],
	detail: [
		{
			index: 'VIEW_CD', name: 'viewCd',
			label: ITP_MSG_LOCALE.label.viewCd,
			width: '10', fixed: false, align: 'center',
			sortable: false, hidden: true
		},
		{
			index: 'PCH_REQ_UNQ_NO', name: 'pchReqUnqNo',
			label: ITP_MSG_LOCALE.label.pchReqUnqNo,  //구매요청번호
			width: '20', fixed: false, align: 'center',
			sortable: false, hidden: true, edittype: 'text',
			 editable: false
		},
		{
			index: 'PCH_REQ_DTL_NO', name: 'pchReqDtlNo',
			label: ITP_MSG_LOCALE.label.pchReqDtlNo, //구매요청항번
			width: '30', fixed: false, align: 'center',
			sortable: true, editable: false, edittype: 'text',
			hidden: true
		},
		{
			index: 'ITEM_ID', name: 'itemId',
			label: ITP_MSG_LOCALE.label.itemId, // 품목아이디
			width: '10', fixed: false, align: 'center',
			sortable: false, editable: false, edittype: 'text',
			hidden: false
		},
		{
			index: 'ITEM_NM', name: 'itemNm',
			label: ITP_MSG_LOCALE.label.itemNm, //품목명
			width: '10', fixed: false, align: 'left',
			sortable: false, editable: false, edittype: 'text',
			hidden: false
		},
		{
			index: 'UNIT_AMT', name: 'unitAmt',
			label: ITP_MSG_LOCALE.label.unitAmt, //단가
			width: '10', fixed: false, align: 'right',
			sortable: false, editable: false, edittype: 'text',
			hidden: false
		},
		{
			index: 'UNIT', name: 'unit',
			label: ITP_MSG_LOCALE.label.unit, //단위
			width: '10', fixed: false, align: 'center',
			sortable: false, editable: false, edittype: 'text',
			hidden: false
		},
		{
			index: 'PCH_REQ_QTY', name: 'pchReqQty',
			label: ITP_MSG_LOCALE.label.pchReqQty, //구매요청수량
			width: '10', fixed: false, align: 'right',
			sortable: false, editable: false, edittype: 'text',
			hidden: false
		},
		{
			index: 'PODR_QTY', name: 'podrQty',
			label: ITP_MSG_LOCALE.label.podrQty, //발주수량
			width: '10', fixed: false, align: 'right',
			sortable: false, editable: true, edittype: 'text',
			editrules: {required: true}, hidden: false
		},
		{
			index: 'PODR_AMT', name: 'podrAmt',
			label: ITP_MSG_LOCALE.label.podrAmt, //발주금액
			width: '10', fixed: false, align: 'right',
			sortable: false, editable: false, edittype: 'text',
			hidden: false
		},
		{
			index: 'DLV_REQ_DT', name: 'dlvReqDt',
			label: ITP_MSG_LOCALE.label.dlvReqDt, //납기요청일
			width: '10', fixed: false, align: 'center',
			sortable: false, editable: false, edittype: 'text',
			hidden: false
		},
		{
			index: 'WHS_PASS_QTY', name: 'whsPassQty',
			label: ITP_MSG_LOCALE.label.whsPassQty, //출고가능수량
			width: '10', fixed: false, align: 'right',
			sortable: false, editable: false, edittype: 'text',
			hidden: false
		},
		{
			index: 'BRAND_UNIT_UNQ_NO', name: 'brandUnitUnqNo',
			label: ITP_MSG_LOCALE.label.brandUnitUnqNo, //브랜드단가고유번호
			width: '10', fixed: false, align: 'center',
			sortable: false, editable: false, edittype: 'text',
			hidden: true
		},
		{
			index: 'STORE_UNIT_UNQ_NO', name: 'storeUnitUnqNo',
			label: ITP_MSG_LOCALE.label.storeUnitUnqNo, //매장단가고유번호
			width: '10', fixed: false, align: 'center',
			sortable: false, editable: false, edittype: 'text',
			hidden: true
		}
	]
};

/*화면공통 Object*/
let pageObj = {
	init: function () {
		this.ui.init();
		this.event.init();
		this.action();
	},
	ui: {
		init: function () {
			this.view();
			this.grid();
			this.ready();
		},
		view: function() {
			// 버튼 권한설정
			fn_proc_btn_auth('POMNG03010');

			// 공통코드 표시
			$('select').each(function() {
				if($(this).data('select-code')) {
					fn_make_select(CODE_LIST, $(this).data('select-code'), $(this).attr('id'));
				}
			});

			// 조회일자 지정
			var now = new Date();
			$('#ITP_TAB_POMNG03010 .input-group.date').datepicker(ITP_DATE_LANGUAGE);
			$('#ITP_FORM_POMNG03010_SEARCH_FROM_DT').datepicker('setDate', new Date(now.setMonth(now.getMonth() - 1)));
			$('#ITP_FORM_POMNG03010_SEARCH_TO_DT').datepicker('setDate', new Date());
			
		},
		grid: function() {
			itp_fn_jqgrid_resize(POMNG03010_GRID_ID, POMNG03010_GRID_LIST, 'lg');
			listObj.empty.init();
			itp_fn_fire_window_resize();
		},
		ready: function() {
			listObj.init();
		}
	},
	action: function () {
		var _this = this;
		// 검색 납품장소
		$('#ITP_FORM_POMNG03010_SSEARCH_SWHS_NM').on('click', function() {
			console.log("=================================");
			_this.popup('SW');
		});
		// 검색 납품장소 텍스트 삭제 버튼 클릭
		$('#ITP_FORM_POMNG03010_SDELETE_SWHS_NM').on('click', function() {
			console.log("=================================");
			$('#ITP_FORM_POMNG03010_SEARCH_SWHS_NM').val('');
			$('#ITP_FORM_POMNG03010_SEARCH_SWHS_ID').val('');
			
		});
		
		// 검색 공급사 
		$('#ITP_FORM_POMNG03010_SSEARCH_SSPPLY_NM').on('click', function() {
			console.log("=================================");
			_this.popup('SS');
		});
		// 검색 텍스트 삭제 버튼 클릭
		$('#ITP_FORM_POMNG03010_SDELETE_SSPPLY_NM').on('click', function() {
			console.log("=================================");
			$('#ITP_FORM_POMNG03010_SEARCH_SSPPLY_NM').val('');
			$('#ITP_FORM_POMNG03010_SEARCH_SSPPLY_ID').val('');
			
		});
		
		
		// 상세 출하창고
		$('#ITP_BTN_POMNG03010_SEARCH_SHMT_WHS_NM').on('click', function() {
			console.log("=================================");
			_this.popup('SHW');
		});
		// 검색 납품장소 텍스트 삭제 버튼 클릭
		$('#ITP_BTN_POMNG03010_DELETE_SHMT_WHS_NM').on('click', function() {
			console.log("=================================");
			$('#ITP_FORM_POMNG03010_DETAIL_SHMT_WHS_ID').val('');
			$('#ITP_FORM_POMNG03010_DETAIL_SHMT_LOCATION').val('');
			$('#ITP_FORM_POMNG03010_DETAIL_SHMT_WHS_NM').val('');
			
		});
		
	},
	popup: function (arg) {
		var popFn ;
		// 팝업
		if (arg == "SW") {
			popFn = this.callback.searWhs;
		} else if (arg == "SS") {
			popFn = this.callback.searSpply;
		}  else if (arg == "SHW") {
			popFn = this.callback.searShmtWhs;
		}
		
		const key = {brandId:fn_make_user_info.get('brandId'),storeId:fn_make_user_info.get('storeId')};
		if (arg == "SW") {
			fn_call_popup('biz', 'BIZPOP_WHS_LOCATION', '#ITP_ASIDE', popFn, key, 'S');
		} else if (arg == "SS") {
			fn_call_popup('biz', 'BIZPOP_STORE_SPPLY', '#ITP_ASIDE', popFn, key, 'S');
		} else if (arg == "SHW") {
			const key1 = {brandId:fn_make_user_info.get('brandId')};
			fn_call_popup('biz', 'BIZPOP_WHS_LOCATION', '#ITP_ASIDE', popFn, key1, 'S');
		}
		
		
	},
	callback: {
		searWhs: function(rowDataPop) {
			console.log(rowDataPop);
			if(rowDataPop) {
				$('#ITP_FORM_POMNG03010_SEARCH_SWHS_NM').val(rowDataPop.whsNm);
				$('#ITP_FORM_POMNG03010_SEARCH_SWHS_ID').val(rowDataPop.whsId);
			}
			
		},
		searSpply: function(rowDataPop) {
			console.log(rowDataPop);
			if(rowDataPop) {
				$('#ITP_FORM_POMNG03010_SEARCH_SSPPLY_NM').val(rowDataPop.spplyNm);
				$('#ITP_FORM_POMNG03010_SEARCH_SSPPLY_ID').val(rowDataPop.spplyId);
			}
			
		},
		searShmtWhs: function(rowDataPop) {
			console.log(rowDataPop);
			if(rowDataPop) {
				$('#ITP_FORM_POMNG03010_DETAIL_SHMT_WHS_NM').val(rowDataPop.whsNm + " - " + rowDataPop.locationNm);
				$('#ITP_FORM_POMNG03010_DETAIL_SHMT_WHS_ID').val(rowDataPop.whsId);
				$('#ITP_FORM_POMNG03010_DETAIL_SHMT_LOCATION').val(rowDataPop.location);
			}
			
		}
	},
	event: {
		init: function () {
			this.button();
		},
		button: function () {
			// 버튼 클릭 이벤트
			$('button').each(function() {
				var id = $(this).attr('id');
				$(this).on('click', function() {
					switch (id) {
						case 'ITP_BTN_POMNG03010_SRH'					: listObj.button.search();			break;	// 조회 버튼 클릭
						case 'ITP_BTN_POMNG03010_POCREATE'				: listObj.button.chkpo(); 		break;	// prpo 버튼
						case 'ITP_BTN_POMNG03010_NEWPOCREATE'			: listObj.button.newpocreate();	break;	// 신규po 버튼
						case 'ITP_BTN_POMNG03010_REJECT'				: listObj.button.reject(); 		break;	// 반려
						case 'ITP_BTN_POMNG03010_PO'					: modifyObj.button.save(); 			break;	// 발주
						case 'ITP_BTN_POMNG03010_CANCELLIST'			: createObj.button.cancel(); 		break;	// 취소/목록 버튼
						case 'ITP_BTN_POMNG03010_DETAIL_ADDROW'			: pageObj.grid.button.addRow(); 	break;	// 품목추가
						case 'ITP_BTN_POMNG03010_DETAIL_DELROW'			: pageObj.grid.button.delRow(); 	break;	// 품목삭제
					}
				});
			});

		}
	},
	switchScreen: function(mode) {
		$('.itp_det_head').find('button[id^="ITP_BTN_POMNG03010_"]').each(function(i) {
			$(this).hide();
		});
		$('#ITP_TAB_POMNG03010').find('div[id$="_CONTAINER"]').each(function(i) {
			$(this).hide();
		});
		if(mode == 'LIST') { // 목록
			$('#ITP_AJAX_POMNG03010_LIST_CONTAINER').show();
			fn_show_btn_auth_array(['#ITP_BTN_POMNG03010_SRH', '#ITP_BTN_POMNG03010_POCREATE','#ITP_BTN_POMNG03010_NEWPOCREATE', '#ITP_BTN_POMNG03010_REJECT']);
			$('#ITP_FORM_POMNG03010_DETAIL_SBRAND_ID').val(fn_make_user_info.get('brandId'));
			$('#ITP_FORM_POMNG03010_DETAIL_SSTORE_ID').val(fn_make_user_info.get('storeId'));
		} else if(mode == 'NPC') { // 신규발주등록
			$('#ITP_AJAX_POMNG03010_DETAIL_CONTAINER').show();
			fn_show_btn_auth_array(['#ITP_BTN_POMNG03010_PO', '#ITP_BTN_POMNG03010_CANCELLIST', '#ITP_BTN_POMNG03010_DETAIL_ADDROW', '#ITP_BTN_POMNG03010_DETAIL_DELROW']);
			$('#ITP_FORM_POMNG03010_DETAIL_BRAND_ID').val(fn_make_user_info.get('brandId'));
			$('#ITP_FORM_POMNG03010_DETAIL_STORE_ID').val(fn_make_user_info.get('storeId'));
			
			$('#ITP_FORM_POMNG03010_DETAIL').find('input, textarea, select, checkbox').each(function(i, elem) {
				$(this).attr('id') === 'ITP_FORM_POMNG03010_DETAIL_VIEW_CD' ? $(this).val('C') : $(this).val('');
				if(elem.type === 'select') {
					$(this).val('').prop('selected', true);
				}
			});
			
			
			// 가맹점 정보 설정
			/*
			$('#ITP_FORM_POMNG03010_DETAIL_AFFL_SHOP_ID').val(fn_make_user_info.get('afflShopId'));
			$('#ITP_FORM_POMNG03010_DETAIL_BRAND_ID').val(fn_make_user_info.get('brandId'));
			$('#ITP_FORM_POMNG03010_DETAIL .fnBrandNm').text(fn_make_user_info.get('brandNm'));

			$('#ITP_FORM_POMNG03010_DETAIL .fnStoreNm').text('(자동부여)');
			$('#ITP_FORM_POMNG03010_DETAIL_STORE_ID').removeAttr('readonly');
			$('#ITP_FORM_POMNG03010_DETAIL .itp_form_info').hide();
			$('#ITP_FORM_POMNG03010_DETAIL .itp_form_info').find('input, select').each(function(i, elem) {
				if($(this).data('check-required')) $(this).data('check-required', '');
				$(this).attr('disabled', true);
			});
			$('#ITP_FORM_POMNG03010_DETAIL .itp_form_change').show();
			$('#ITP_FORM_POMNG03010_DETAIL .itp_form_change').find('input, select').each(function(i, elem) {
				if($(this).data('check-required')) $(this).data('check-required', 'empty');
				$(this).attr('disabled', false);
			});
			*/
			var now = new Date();
			$('#ITP_TAB_POMNG03010 .input-group.date').datepicker(ITP_DATE_LANGUAGE);
			$('#ITP_FORM_POMNG03010_DETAIL_DLV_REQ_DT').datepicker('setDate', new Date(now.setDate(now.getDate()+5)));
		} else if(mode == 'POC') { // 구매요청 발주
			$('#ITP_AJAX_POMNG03010_DETAIL_CONTAINER').show();
			fn_show_btn_auth_array(['#ITP_BTN_POMNG03010_PO', '#ITP_BTN_POMNG03010_CANCELLIST']);
			$('#ITP_FORM_POMNG03010_DETAIL_BRAND_ID').val(fn_make_user_info.get('brandId'));
			$('#ITP_FORM_POMNG03010_DETAIL_STORE_ID').val(fn_make_user_info.get('storeId'));
			/*
			$('#ITP_FORM_POMNG03010_DETAIL_AFFL_SHOP_ID').val(fn_make_user_info.get('afflShopId'));
			$('#ITP_FORM_POMNG03010_DETAIL_BRAND_ID').val(fn_make_user_info.get('brandId'));
			$('#ITP_FORM_POMNG03010_DETAIL .fnBrandNm').text(fn_make_user_info.get('brandNm'));

			$('#ITP_FORM_POMNG03010_DETAIL_STORE_ID').attr('readonly', true);
			// $('#ITP_BTN_POMNG03010_RESET_PW').show();
			$('#ITP_FORM_POMNG03010_DETAIL .itp_form_info').show();
			$('#ITP_FORM_POMNG03010_DETAIL .itp_form_info').find('input, select').each(function(i, elem) {
				if($(this).data('check-required')) $(this).data('check-required', 'empty');
				$(this).attr('disabled', false);
			});
			$('#ITP_FORM_POMNG03010_DETAIL .itp_form_change').hide();
			$('#ITP_FORM_POMNG03010_DETAIL .itp_form_change').find('input, select').each(function(i, elem) {
				if($(this).data('check-required')) $(this).data('check-required', '');
				$(this).attr('disabled', true);
			});
			*/

		} 
		/*
		else if(mode == 'VIEW') { // 보기
			$('#ITP_AJAX_POMNG03010_VIEW_CONTAINER').show();
			fn_show_btn_auth_array(['#ITP_BTN_POMNG03010_MODIFY', '#ITP_BTN_POMNG03010_CANCELLIST']);
		}
		*/
	}
};

/*목록화면 Object*/
let listObj = {
	init: function () {
		this.grid.init();
	},
	itp_POMNG03010_search: false,
	button: {
		search: function() {
			listObj.itp_POMNG03010_search = true;
			let param = $('#ITP_FORM_POMNG03010_SEARCH').serializeObject();
			param.gridSize = $.jgrid.defaults.rowNum;
			param.gridPage = $.jgrid.defaults.page;
			$(POMNG03010_GRID_ID).setGridParam({'postData': JSON.stringify(param)}).trigger('reloadGrid');
		},
		pocreate: function(param) {
			pageObj.switchScreen('POC');
			itp_fn_form_clear_validate(null, '#ITP_FORM_POMNG03010_DETAIL');
			modifyObj.init(param);
		},
		newpocreate: function() {
			pageObj.switchScreen('NPC');
			itp_fn_form_clear_validate(null, '#ITP_FORM_POMNG03010_DETAIL');
			createObj.init();
		},
		reject: function() {
			//팝업 오픈
			//pageObj.switchScreen('NPC');
			//itp_fn_form_clear_validate(null, '#ITP_FORM_POMNG03010_DETAIL');
			//createObj.init();
		},
		chkpo: function() {	
			let gridUpdateData = [];
			console.log("==================");
			const rowKey = $(POMNG03010_GRID_ID).getGridParam('selrow');
			console.log(rowKey);
		    if (!rowKey) {
				console.log("################");
		    	return;
		    }
	
		    var selectedIds = $(POMNG03010_GRID_ID).getGridParam('selarrrow');
			
		    for (var i=selectedIds.length-1; i>=0; i--) {
				gridUpdateData.push($(POMNG03010_GRID_ID).jqGrid('getRowData', selectedIds[i]));	
			}
			
			let param = {};
			param.brandId=fn_make_user_info.get('brandId');
			param.gridUpdateData = gridUpdateData;
			console.log(JSON.stringify(param));
			var chkFn = function(result) {
				console.log(result);
				if (result.code == "Y") {
					//발수 생성화면으로 전화 
					listObj.button.pocreate(param);
				}
			};
			fn_ajax_call(API_DETAIL_POPASS_CHK, JSON.stringify(param), chkFn, 'POST');
		}, 
	},
	empty: {
		init: function() {
			var _this = this;
			this.push();
			$(POMNG03010_GRID_EMPTY).on('click', function() {
				_this.back();
				_this.itp_POMNG03010_param.gridSize = $.jgrid.defaults.rowNum;
				$(POMNG03010_GRID_ID).setGridParam({'postData': JSON.stringify(_this.itp_POMNG03010_param)}).trigger('reloadGrid');
			});
		},
		itp_POMNG03010_param: {},
		push: function() {
			let param = $('#ITP_FORM_POMNG03010_SEARCH').serializeObject();
			listObj.itp_POMNG03010_param = param;
		},
		back: function() {
			$('#ITP_FORM_POMNG03010_SEARCH_FROM_DT').val(this.itp_POMNG03010_param.fromDt);
			$('#ITP_FORM_POMNG03010_SEARCH_TO_DT').val(this.itp_POMNG03010_param.toDt);
			$('#ITP_FORM_POMNG03010_SEARCH_SPPLY_ID').val(this.itp_POMNG03010_param.sspplyId);
			$('#ITP_FORM_POMNG03010_SEARCH_SPPLY_NM').val(this.itp_POMNG03010_param.sspplyNm);
			$('#ITP_FORM_POMNG03010_SEARCH_WHS_NM').val(this.itp_POMNG03010_param.swhsNm);
			$('#ITP_FORM_POMNG03010_SEARCH_WHS_ID').val(this.itp_POMNG03010_param.swhsId);
			$('#ITP_FORM_POMNG03010_SEARCH_ITEM_NM').val(this.itp_POMNG03010_param.sitemNm);
		}
	},
	grid: {
		init: function () {
			// 데이터 없을때
			listObj.empty.push();
			this.search();
		},
		colModel: gridColModel.list,
		search: function() {
			pageObj.switchScreen('LIST');
			this.unload();
			this.load();
		},
		load: function() {
			let param = $('#ITP_FORM_POMNG03010_SEARCH').serializeObject();
			param.gridSize = $.jgrid.defaults.rowNum;
			
			var option = {
				multiselect: true,
				autowidth: true,
				gridId: POMNG03010_GRID_ID,
				colModel: gridColModel.list,
				param: param,
				url: DOMAIN + API_DETAIL_GRID_LIST,
				pager: POMNG03010_GRID_PAGER,
				loadComplete: function(data) {
					console.log(data);
					itp_fn_grid_load_complete(data, POMNG03010_GRID_ID, true, 'number', 'POMNG03010', listObj.itp_POMNG03010_search, listObj.empty, true, data.gridRecords, true);
					var ids = $(POMNG03010_GRID_ID).getDataIDs();
					$.each(ids, function(idx, rowId) {
						$(POMNG03010_GRID_ID).jqGrid('setCell', rowId, 'storeId', '', ITP_GRID_COL_STYLE.link);
					});
				},
				onPaging: function(action) {
					itp_fn_grid_paging(POMNG03010_GRID_ID, action, param);
				}
			};
			itp_fn_grid_make_remote(option);
		},
		button: {
		},
		unload : function() {
			$.jgrid.gridUnload(POMNG03010_GRID_ID);
		},
		clearData : function() {
			$(POMNG03010_GRID_ID).jqGrid('clearGridData', true);
			$(POMNG03010_GRID_LIST).find('.ui-jqgrid-bdiv').css('min-height', '100px');
			$(POMNG03010_GRID_EMPTY).html(ITP_MSG_LOCALE.message.grid.noData);
			$(POMNG03010_GRID_EMPTY).show();
		}
	}
};

/*수정화면 Object*/
let modifyObj = {
	init: function (param) {
		this.load(param);
	},
	button: {
		modify: function (param) {
			itp_fn_form_clear_validate(null, '#ITP_FORM_POMNG03010_DETAIL');
			const selectVal = $('#ITP_FORM_POMNG03010_VIEW_STORE_ID').val();
			const key = {brandId:fn_make_user_info.get('brandId'), storeId: selectVal, viewCd: 'R'};
			var param = $.param(key);
			console.log(param);
			modifyObj.load(param);
		},
		save: function() {
			const formId = '#ITP_FORM_POMNG03010_DETAIL';
			itp_fn_form_clear_validate(null, formId);

			// console.log($(formId).serializeObject());
			if (itp_fn_form_event.isValid(formId)) {
				var modalFn = {
					callBack: () => {
						itp_fn_form_event.removeChar('#ITP_FORM_OPER03010_DETAIL');
						
						let gridInsertData = [];
						const rowData = $(POMNG03010_DETAIL_GRID_ID).getRowData();
						
						$.each(rowData, function(key, value) {
							gridInsertData.push(value);
						});
		
						let param = $(formId).serializeObject();
						param.gridInsertData = gridInsertData;
						
						var searhFn = function () {
							ITP_FORM_POMNG03010_DETAIL_IS_WRITING = false;
							modifyObj.grid.clearData();
							createObj.button.cancel();
						}
						fn_ajax_call(API_DETAIL_SAVE, JSON.stringify(param), searhFn, 'POST');
					}
				};
				itp_fn_modal_confirm('발주 진행 하시겠습니까?', modalFn);
			}
		}
	},
	
	load: function(param) {
		fn_ajax_call(API_DETAIL_PO_INIT_INFO, JSON.stringify(param), this.callback, 'POST');
	},
	callback: function (result) {
		console.log(result);
		pageObj.switchScreen('POC');
		$('#ITP_FORM_POMNG03010_DETAIL #ITP_FORM_POMNG03010_DETAIL_VIEW_CD').val('C');
		$('#ITP_FORM_POMNG03010_DETAIL #ITP_FORM_POMNG03010_DETAIL_BRAND_ID').val(result.brandId);
		$('#ITP_FORM_POMNG03010_DETAIL .fnBrandNm').text(result.brandNm);
		$('#ITP_FORM_POMNG03010_DETAIL #ITP_FORM_POMNG03010_DETAIL_STORE_ID').val(result.storeId);
		$('#ITP_FORM_POMNG03010_DETAIL #ITP_FORM_POMNG03010_DETAIL_SPPLY_ID').val(result.spplyId);
		$('#ITP_FORM_POMNG03010_DETAIL .fnPchReqNm').text(result.spplyNm);
		$('#ITP_FORM_POMNG03010_DETAIL .fnPodrDt').text(result.podrDt);
		$('#ITP_FORM_POMNG03010_DETAIL .fnWhsNm').text(result.dlvPlace);
		$('#ITP_FORM_POMNG03010_DETAIL #ITP_FORM_POMNG03010_DETAIL_WHS_ID').val(result.whsId);
		$('#ITP_FORM_POMNG03010_DETAIL #ITP_FORM_POMNG03010_DETAIL_LOCATION').val(result.location);
		$('#ITP_FORM_POMNG03010_DETAIL #ITP_FORM_POMNG03010_DETAIL_PODR_MGR_ID').val(result.podrMgrId);
		$('#ITP_FORM_POMNG03010_DETAIL .fnPodrMgrNm').text(result.podrMgrNm);
		$('#ITP_FORM_POMNG03010_DETAIL #ITP_FORM_POMNG03010_DETAIL_PODR_MGR_TEL_NO').val(result.podrMgrTelNo);
		$('#ITP_FORM_POMNG03010_DETAIL #ITP_FORM_POMNG03010_DETAIL_DLV_DVSN').val(result.dlvDvsn);
		//$('#ITP_FORM_POMNG03010_DETAIL #ITP_FORM_POMNG03010_DETAIL_').val(result.dlvDvsnNm);
		$('#ITP_FORM_POMNG03010_DETAIL .fnPodrAmt').text(result.podrTotalAmt);
		$('#ITP_FORM_POMNG03010_DETAIL #ITP_FORM_POMNG03010_DETAIL_DLV_REQ_DT').val(result.dlvReqDt);
		$('#ITP_FORM_POMNG03010_DETAIL #ITP_FORM_POMNG03010_DETAIL_SHMT_WHS_ID').val(result.shmtWhsId);
		$('#ITP_FORM_POMNG03010_DETAIL #ITP_FORM_POMNG03010_DELETE_SHMT_WHS_NM').val(result.shmtWhsNm + " - " + result.shmtLocationNm );
		$('#ITP_FORM_POMNG03010_DETAIL #ITP_FORM_POMNG03010_DETAIL_SHMT_LOCATION').val(result.shmtLocation);
		
		// 품목  리스트 조회
		modifyObj.grid.init('DETAIL', result.itemList);
		// modifyObj.grid.load(result.spplyMgrList);
	},
	grid: {
		init: function(mode, gridRows) {
			this.gridId = POMNG03010_DETAIL_GRID_ID;
			this.gridList = POMNG03010_DETAIL_GRID_LIST;
			this.gridEmpty = POMNG03010_DETAIL_GRID_EMPTY;
			this.gridRows = gridRows;
			this.load(mode, gridRows);
		},
		gridId: '',
		mode: 'DETAIL',
		button: {},
		gridList: '',
		gridEmpty: '',
		gridRows: '',
		load: function(mode, gridRows) {
			var _this = this;
			var option = {
				gridId: _this.gridId,
				colModel: gridColModel.detail,
				data: gridRows,
				cellEdit: true,
				multiselect: false,
				// cellEdit: (mode !== 'VIEW'),
				loadComplete: function(data) {
					console.log(data);
					$(_this.gridList).find('.ui-jqgrid .ui-jqgrid-bdiv').css('overflow-x', 'hidden');
					(Array.isArray(data.rows) && data.rows.length === 0) ? $(_this.gridEmpty).show() : $(_this.gridEmpty).hide();
				},
				onCellSelect: function(rowid, cellIdx, cellValue) {
					console.log('mode ===> ' + mode);
					POMNG03010_GRID_LAST_ROW_ID = itp_fn_set_data_editable(rowid, cellIdx, POMNG03010_GRID_LAST_ROW_ID, _this.gridId, ['actionId']);
				},
				afterSaveCell: function(rowid,name,val,iRow,iCol) {
					// 구매요청금액 계산 (기존금액과 )
					var	unitAmt = jQuery(POMNG03010_DETAIL_GRID_ID).jqGrid('getCell',rowid,iCol-3);
					jQuery(POMNG03010_DETAIL_GRID_ID).jqGrid('setRowData',rowid,{podrAmt: parseInt(val)*parseInt(unitAmt)});	
					
					// 그리드 포문으로 금액 재계산후 구매요청금액에 넣어줌
					_this.recal();
				}
			};
			itp_fn_grid_make_local(option);
		},
		recal: function() {
			//PCH_REQ_AMT
			console.log("==========================================");
			const rowData = $(POMNG03010_DETAIL_GRID_ID).getRowData();
			var podrAmt = 0 ;
			console.log("####################################");
			$.each(rowData, function(key, value) {
				console.log(rowData);
				if (value.podrAmt != null && value.podrAmt != "" && value.viewCd != "D") {
					podrAmt = podrAmt + parseInt(value.podrAmt) ;
				}
				
			});
			$('#ITP_FORM_POMNG03010_DETAIL .fnPodrAmt').text(podrAmt);
		},
		clearData : function() {
			$(POMNG03010_DETAIL_GRID_ID).jqGrid('clearGridData', true);
			$(POMNG03010_DETAIL_GRID_LIST).find('.ui-jqgrid-bdiv').css('min-height', '100px');
			$(POMNG03010_DETAIL_GRID_EMPTY).html(ITP_MSG_LOCALE.message.grid.noData);
			$(POMNG03010_DETAIL_GRID_EMPTY).show();
		}
	},
};

/*신규화면 Object*/
let createObj = {
	init: function () {
		$('#ITP_FORM_POMNG03010_DETAIL_BRAND_ID').val(fn_make_user_info.get('brandId'));
		$('#ITP_FORM_POMNG03010_DETAIL_STORE_ID').val(fn_make_user_info.get('storeId'));
		
	},
	button: {
		cancel: function() {
			document.getElementById('ITP_FORM_POMNG03010_DETAIL').reset();
			listObj.grid.search();
		},
		save: function() {
			const formId = '#ITP_FORM_POMNG03010_DETAIL';
			itp_fn_form_clear_validate(null, formId);

			// console.log($(formId).serializeObject());
			if (itp_fn_form_event.isValid(formId)) {
				var modalFn = {
					callBack: (args) => {
						itp_fn_form_event.removeChar('#ITP_FORM_OPER03010_DETAIL');
						let param = $(formId).serializeObject();
						console.log(JSON.stringify(param));
						var searhFn = function () {
							ITP_FORM_POMNG03010_DETAIL_IS_WRITING = false;
							listObj.grid.search();
						}
						fn_ajax_call(API_DETAIL_SAVE, JSON.stringify(param), searhFn, 'POST');
					}
				};
				itp_fn_modal_confirm('저장 하시겠습니까?', modalFn);
			}
		}
	}
};
